@@ -1,4 +1,4 @@
-/*	$calcurse: utils.c,v 1.45 2008/04/12 21:14:03 culot Exp $	*/
+/*	$calcurse: utils.c,v 1.48 2008/08/11 18:08:45 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
@@ -442,19 +442,22 @@ status_bar (void)
   binding_t eday = { "^HL", _("-+1 Day") };
   binding_t ewek = { "^KJ", _("-+1 Week") };
   binding_t othr = { "  O", _("OtherCmd") };
+  binding_t today = {" ^G", _("Today") };
+  binding_t weekb = {"  0", _("beg Week") };
+  binding_t weeke = {"  $", _("end Week") };
 
   binding_t *binding[TOTAL_CMDS] = {
     /* calendar keys */
-    &help, &quit, &save, &export, &day, &week, &tab, &togo, &appt,
-    &todo, &conf, &othr, &eday, &ewek, &draw, &othr,
+    &help, &quit, &save, &export, &day, &week, &weekb, &weeke, &tab,
+    &togo, &conf, &othr, &appt, &todo, &eday, &ewek, &draw, &today, &othr,
     /* appointment keys */
     &help, &quit, &save, &export, &add, &del, &edit, &view, &rept,
     &updn, &flag, &othr, &enote, &vnote, &appt, &todo, &eday, &ewek,
-    &conf, &togo, &tab, &draw, &othr,
+    &conf, &togo, &tab, &draw, &today, &othr,
     /* todo keys */
     &help, &quit, &save, &export, &add, &del, &edit, &view, &prio,
     &updn, &tab, &othr, &enote, &vnote, &appt, &todo, &eday, &ewek,
-    &conf, &togo, &draw, &othr
+    &conf, &togo, &draw, &today, &othr
   };
 
   /* Total length of a command. */
@@ -553,39 +556,39 @@ date_sec2date_str (long sec, char *datefmt)
   return (datestr);
 }
 
-/* 
- * Return a string containing an iCal date, given a date in 
- * seconds. This is used to build all-day long iCal VEVENT 
- * (calcurse event equivalent).
- */
+/* Generic function to format date. */
 void
-date_sec2ical_date (long sec, char *ical_date)
+date_sec2date_fmt (long sec, const char *fmt, char *datef)
 {
-#define DATELENGTH	9
-
   struct tm *lt;
   time_t t;
 
   t = sec;
   lt = localtime (&t);
-  strftime (ical_date, DATELENGTH, "%Y%m%d", lt);
+  strftime (datef, BUFSIZ, fmt, lt);
 }
 
 /* 
- * Return a string containing an iCal date-time, given a date in 
- * seconds. This is used to build iCal VEVENT (calcurse appointment equivalent). 
+ * Used to change date by adding a certain amount of days or weeks.
  */
-void
-date_sec2ical_datetime (long sec, char *ical_datetime)
+long
+date_sec_change (long date, int delta_month, int delta_day)
 {
-#define DATETIMELENGTH	16
-
   struct tm *lt;
   time_t t;
-
-  t = sec;
+  
+  t = date;
   lt = localtime (&t);
-  strftime (ical_datetime, DATETIMELENGTH, "%Y%m%dT%H%M%S", lt);
+  lt->tm_mon += delta_month;
+  lt->tm_mday += delta_day;
+  t = mktime (lt);
+  if (t == -1)
+    {
+      fputs (_("FATAL ERROR in date_sec_change: failure in mktime\n"), stderr);
+      exit (EXIT_FAILURE);
+    }
+
+  return t;
 }
 
 /* 
@@ -764,15 +767,11 @@ other_status_page (int panel)
     default:
       ierror (error, IERROR_FATAL);
     }
-  max_page = ceil (nb_item / (2 * CMDS_PER_LINE)) + 1;
+  max_page = ceil (nb_item / (2 * CMDS_PER_LINE + 1)) + 1;
   if (status_page < max_page)
-    {
-      status_page++;
-    }
+    status_page++;
   else
-    {
-      status_page = 1;
-    }
+    status_page = 1;
 }
 
 /* Returns the beginning of current day in seconds from 1900. */
