@@ -1,4 +1,4 @@
-/*	$calcurse: utils.h,v 1.29 2008/04/12 21:14:03 culot Exp $	*/
+/*	$calcurse: utils.h,v 1.32 2008/08/11 18:08:45 culot Exp $	*/
 
 /*
  * Calcurse - text-based organizer
@@ -38,9 +38,9 @@
 
 #define SPC		32	/* ASCII code for white space */
 
-#define NB_CAL_CMDS	16	/* number of commands while in cal view */
-#define NB_APP_CMDS	23	/* same thing while in appointment view */
-#define NB_TOD_CMDS	22	/* same thing while in todo view */
+#define NB_CAL_CMDS	19	/* number of commands while in cal view */
+#define NB_APP_CMDS	24	/* same thing while in appointment view */
+#define NB_TOD_CMDS	23	/* same thing while in todo view */
 #define TOTAL_CMDS	NB_CAL_CMDS + NB_APP_CMDS + NB_TOD_CMDS
 #define NB_PANELS	3	/* 3 panels: CALENDAR, APPOINTMENT, TODO */
 #define CMDS_PER_LINE	6	/* max number of commands per line */
@@ -89,8 +89,8 @@ void    status_bar (void);
 long    date2sec (date_t, unsigned, unsigned);
 char   *date_sec2hour_str (long);
 char   *date_sec2date_str (long, char *);
-void    date_sec2ical_date (long, char *);
-void    date_sec2ical_datetime (long, char *);
+void    date_sec2date_fmt (long, const char *, char *);
+long    date_sec_change (long, int, int);
 long    update_time_in_date (long, unsigned, unsigned);
 long    get_sec_date (date_t);
 long    min2sec (unsigned);
